<?php

/**
 * Initialize theme settings
 */
if (is_null(theme_get_setting('user_notverified_display')) || theme_get_setting('rebuild_registry')) {
  global $theme_key;
	
  // Auto-rebuild the theme registry during theme development.
  if(theme_get_setting('rebuild_registry')) {
    drupal_set_message(t('The theme registry has been rebuilt. <a href="!link">Turn off</a> this feature on production websites.', array('!link' => url('admin/build/themes/settings/' . $GLOBALS['theme']))), 'warning');
  }
  
  /**
   * The default values for the theme variables. Make sure $defaults exactly
   * matches the $defaults in the theme-settings.php file.
   */
  $defaults = array(
    'user_notverified_display'              => 1,
    'breadcrumb_display'                    => 0,
    'rebuild_registry'                      => 0,
    'use_nice_menus'                        => 0,
    'admin_remove_sidebars'                 => 0,
    'grid_layout'                           => 'sidebar_second',
    'sidebar_first_width'                   => 3,
    'sidebar_second_width'                  => 3,
    'inset_column_width'                    => 3,
    'wider_column'                          => 0,
    'container'                             => 16,
  );
  
  // Get default theme settings.
  $settings = theme_get_settings($theme_key);
  
  // Save default theme settings
  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge($defaults, $settings)
  );
  // Force refresh of Drupal internals
  theme_get_setting('', TRUE);
}

/**
 * Modify theme variables
 */
function hydrogen_preprocess(&$vars) {
  global $user;                                            // Get the current user
  $vars['is_admin'] = in_array('admin', $user->roles);     // Check for Admin, logged in
  $vars['logged_in'] = ($user->uid > 0) ? TRUE : FALSE;
}

/**
 * Implementation of template_preprocess_page().
 */
function hydrogen_preprocess_page(&$vars, $hook) {
  // For easy printing of variables.
  $vars['logo_img'] = $vars['logo'] ? theme('image', substr($vars['logo'], strlen(base_path())), t('Home'), t('Home')) : '';
  $vars['linked_logo_img'] = $vars['logo_img'] ? l($vars['logo_img'], '<front>', array('attributes' => array('rel' => 'home'), 'title' => t('Home'), 'html' => TRUE)) : '';
  $vars['linked_site_name'] = $vars['site_name'] ? l($vars['site_name'], '<front>', array('attributes' => array('rel' => 'home'), 'title' => t('Home'))) : '';
  $vars['main_menu_links'] = theme('links', $vars['primary_links'], array('class' => 'links main-menu'));
  $vars['secondary_menu_links'] = theme('links', $vars['secondary_links'], array('class' => 'links secondary-menu'));

  // Make sure framework styles are placed above all others.
  $vars['css_alt'] = hydrogen_css_reorder($vars['css']);
  $vars['styles'] = drupal_get_css($vars['css_alt']);

  // Hide breadcrumb on all pages
  if (theme_get_setting('breadcrumb_display') == 0) {
    unset($vars['breadcrumb']);
  }

  // Re-theme primary links using Nice Menus
  if (theme_get_setting('use_nice_menus') && module_exists('nice_menus')) {
    $vars['main_menu_links'] = theme_nice_menu_primary_links();
    unset($vars['secondary_menu_links']);
  }

  // Set up layout variable.
  $variables['layout'] = 'none';
  if (!empty($variables['sidebar_first'])) {
    $variables['layout'] = 'sidebar-first';
  }
  if (!empty($variables['sidebar_second'])) {
    $variables['layout'] = ($variables['layout'] == 'sidebar-first') ? 'both' : 'sidebar-second';
  }

  // Remove sidebars in Admin area
  if (($value = theme_get_setting('admin_remove_sidebars')) && (substr($_GET['q'], 0, 5) == 'admin') && (substr($_GET['q'], 12, 5) <> 'block')) {
    if (in_array($value, array('sidebar_first','sidebar_second'))) {
      unset($vars[$value]);
    }
    elseif ($value == 'both') {
      unset($vars['sidebar_first'], $vars['sidebar_second']);
    }
  }

  // Add a subtitle if one exists
  if ($node = $vars['node']) {
    $vars['subtitle'] = $node->field_subtitle[0]['value'];
  }

  // Configure number of columns from settings.
  $vars['container'] = theme_get_setting('container');

  // Configure grid layout from settings.
  $vars['grid_layout'] = $grid_layout = theme_get_setting('grid_layout');
 
  // Get configurable region widths from theme settings.
  $columns['sidebar_first']  = theme_get_setting('sidebar_first_width');
  $columns['sidebar_second'] = theme_get_setting('sidebar_second_width');
  $columns['inset'] = theme_get_setting('inset_column_width');
  $wide_single = (bool) theme_get_setting('wider_column');

  if ($wide_single && !$vars['sidebar_first']) $columns['sidebar_second'] = $columns['sidebar_second'] + 1;
  if ($wide_single && !$vars['sidebar_second']) $columns['sidebar_first'] = $columns['sidebar_first'] + 1;

  // Build layout and set up variables for grid sizing.
  hydrogen_layout($vars, $grid_layout, $columns);  

  // Get current body classes and remove the no-sidebars class added by core
  $body_classes = explode(' ', str_replace('no-sidebars', '', $vars['body_classes']));

  // Remove any empty values from the explode
  $body_classes = array_filter($body_classes);
  
  // Add body classes for our sidebars.
  if ($vars['sidebar_first'] && !$vars['sidebar_second']) {
    $body_classes[] = 'sidebar-first';
    $body_classes[] = 'one-sidebar'; 
  }
  elseif (!$vars['sidebar_first'] && $vars['sidebar_second'])  { 
    $body_classes[] = 'sidebar-second';
    $body_classes[] = 'one-sidebar'; 
  }
  elseif ($vars['sidebar_first'] && $vars['sidebar_second']) {
    $body_classes[] = 'two-sidebars'; 
  }
  else {
    $body_classes[] = 'no-sidebars';
  }

  // Add a class for grid layout.
  $body_classes[] = 'layout-'. form_clean_id($vars['grid_layout']);

  $vars['body_classes'] = implode(' ', $body_classes);
}

/**
 * Internal callback for handling grid layout
 */
function hydrogen_layout(&$vars, $grid_layout, $columns = array(), $container = '') {
  // Make sure the variable we're working with is the one that was passed to the function
  $vars['grid_layout'] = $grid_layout;

  // The number of columns to work with.
  $vars['container'] = $c = $container ? $container : theme_get_setting('container'); 

  // content wrapper 
  if ($grid_layout == 'sidebar_second' || $grid_layout == 'both_sidebar_second') {
    $vars['grid_content_wrapper'] = hydrogen('grid-'. $c, $vars['sidebar_second'], $columns['sidebar_second']);
  }
  elseif($grid_layout == 'sidebar_first') {
    // $vars['grid_content_wrapper'] = hydrogen('grid-16', $vars['sidebar_first'], $columns['sidebar_first']);
    $vars['grid_content_wrapper'] = '';
  }
  else {
    $vars['grid_content_wrapper'] = 'container-'. $c;
  }

  // sub feature
  if (in_array($grid_layout, array('sidebar_second', 'both_sidebar_second'))) {
    $vars['grid_sub_feature'] = hydrogen('grid-'. $c, $vars['sidebar_second'], $columns['sidebar_second']) .' alpha omega';
  }
  elseif ($grid_layout == 'sidebar_first')  {
    $vars['grid_sub_feature'] = hydrogen('grid-'. $c, $vars['sidebar_first'], $columns['sidebar_first']) .' omega';
  }
  else {
    $vars['grid_sub_feature'] = 'container-'. $c .' alpha omega';
  }

  // sidebar_first side bar
  $vars['grid_sidebar_first'] = 'grid-'. $columns['sidebar_first']; // .' alpha';
  if ($grid_layout == 'sidebar_second') {
    $vars['grid_sidebar_first'] = $vars['grid_sidebar_first'] . ' alpha';
  }

  // main
  $vars['grid_main'] = hydrogen('grid-'. $c, $vars['sidebar_first'], $columns['sidebar_first'], $vars['sidebar_second'], $columns['sidebar_second']); // .' omega';
  if ($grid_layout == 'sidebar_second' || $grid_layout == 'both_sidebar_second') {
    $vars['grid_main'] = $vars['grid_main'] . ' omega';
    if (!$vars['sidebar_first']) {
      $vars['grid_main'] = $vars['grid_main'] .' alpha';
    }
  }

  // inset column
  $vars['grid_inset'] = 'grid-'. $columns['inset'] .' omega';

  // sidebar_second side bar 
  $vars['grid_sidebar_second'] = hydrogen('grid-'. $columns['sidebar_second']);
  
  // Additional definitions.
  $vars['grid_page'] = 'container-'. $c;
  $vars['grid_header_region'] = 'grid-'. $c;
  $vars['grid_branding'] = 'grid-' . $c;
  $vars['grid_logo'] = '';
  $vars['grid_site_name'] = '';
  $vars['grid_site_slogan'] = '';
  $vars['grid_mission'] = '';
  $vars['grid_site_menu'] = 'grid-'. $c;
  $vars['grid_feature'] = 'container-'. $c;
  $vars['grid_footer'] = 'container-'. $c;
  $vars['grid_footer_message'] = 'grid-'. $c;
}

/**
 * Contextually adds 960 Grid System classes. 
 * Derived from the Ninesixty theme ns() function.
 *
 * The first parameter passed is the *default class*. All other parameters must
 * be set in pairs like so: "$variable, 3". The variable can be anything available
 * within a template file and the integer is the width set for the adjacent box
 * containing that variable.
 *
 *  class="<?php print hydrogen('grid-16', $var_a, 6); ?>"
 *
 * If $var_a contains data, the next parameter (integer) will be subtracted from
 * the default class. See the README.txt file.
 */
function hydrogen() {
  $args = func_get_args();
  $default = array_shift($args);
  // Get the type of class, i.e., 'grid', 'pull', 'push', etc.
  // Also get the default unit for the type to be procesed and returned.
  list($type, $return_unit) = explode('-', $default);

  // Process the conditions.
  $flip_states = array('var' => 'int', 'int' => 'var');
  $state = 'var';
  foreach ($args as $arg) {
    if ($state == 'var') {
      $var_state = !empty($arg);
    }
    elseif ($var_state) {
      $return_unit = $return_unit - $arg;
    }
    $state = $flip_states[$state];
  }

  $output = '';
  // Anything below a value of 1 is not needed.
  if ($return_unit > 0) {
    $output = $type . '-' . $return_unit;
  }
  return $output;
}

/**
 * Adds a class for the style of view  
 * (e.g., node, teaser, list, table, etc.)
 * (Requires views-view.tpl.php file in theme directory)
 */
function hydrogen_preprocess_views_view(&$vars) {
  $vars['css_name'] = $vars['css_name'] .' view-style-'. views_css_safe(strtolower($vars['view']->type));
}

/**
 * This rearranges how the style sheets are included so the framework styles
 * are included first.
 *
 * Sub-themes can override the framework styles when it contains css files with
 * the same name as a framework style. This can be removed once Drupal supports
 * weighted styles.
 */
function hydrogen_css_reorder($css) {
  global $theme_info, $base_theme_info;

  // Dig into the framework .info data.
  $framework = !empty($base_theme_info) ? $base_theme_info[0]->info : $theme_info->info;

  // Pull framework styles from the themes .info file and place them above all stylesheets.
  if (isset($framework['stylesheets'])) {
    foreach ($framework['stylesheets'] as $media => $styles_from_960) {
      // Setup framework group.
      if (isset($css[$media])) {
        $css[$media] = array_merge(array('framework' => array()), $css[$media]);
      }
      else {
        $css[$media]['framework'] = array();
      }
      foreach ($styles_from_960 as $style_from_960) {
        // Force framework styles to come first.
        if (strpos($style_from_960, 'framework') !== FALSE) {
          $framework_shift = $style_from_960;
          $remove_styles = array($style_from_960);
          // Handle styles that may be overridden from sub-themes.
          foreach ($css[$media]['theme'] as $style_from_var => $preprocess) {
            if ($style_from_960 != $style_from_var && basename($style_from_960) == basename($style_from_var)) {
              $framework_shift = $style_from_var;
              $remove_styles[] = $style_from_var;
              break;
            }
          }
          $css[$media]['framework'][$framework_shift] = TRUE;
          foreach ($remove_styles as $remove_style) {
            unset($css[$media]['theme'][$remove_style]);
          }
        }
      }
    }
  }

  return $css;
}
