<?php

/**
* Implementation of THEMEHOOK_settings() function.
*
* @param $saved_settings
*   array An array of saved settings for this theme.
* @return
*   array A form array.
*/
function phptemplate_settings($saved_settings) {
  // Get the node types
  // $node_types = node_get_types('names');
 
  /**
   * The default values for the theme variables. Make sure $defaults exactly
   * matches the $defaults in the template.php file.
   */
   $defaults = array(
    'user_notverified_display'              => 1,
    'breadcrumb_display'                    => 0,
    'rebuild_registry'                      => 0,
    'use_nice_menus'                        => 0,
    'admin_remove_sidebars'                 => 0,
    'grid_layout'                           => 'sidebar_second',
    'sidebar_first_width'                   => 3,
    'sidebar_second_width'                  => 3,
    'inset_column_width'                    => 3,
    'wider_column'                          => 0,
    'container'				    => 16,
   );
   

  // Make the default content-type settings the same as the default theme settings,
  // so we can tell if content-type-specific settings have been altered.
  $defaults = array_merge($defaults, theme_get_settings());

  // Merge the saved variables and their default values
  $settings = array_merge($defaults, $saved_settings);
 
  // Create theme settings form widgets using Forms API
  
  // Base Fieldset
  $form['base'] = array(
    '#type' => 'fieldset',
    '#title' => t('Theme settings'),
    '#description' => t('Additional configuration options'),
    '#collapsible' => TRUE,
    '#collapsed' => false,
  );
  
  // General Settings
  $form['base']['general_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#attributes' => array('cs' => 'general_settings'),
  );
  
  // Breadcrumb
  $form['base']['general_settings']['breadcrumb_display'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display breadcrumb'),
    '#default_value' => $settings['breadcrumb_display'],
  );

  // Theme menu links as nice menus
  if (module_exists('nice_menus')) {
    $form['base']['general_settings']['use_nice_menus'] = array(
      '#type' => 'checkbox',
      '#title' => t('Display primary links using Nice Menus'),
      '#default_value' => $settings['use_nice_menus'],
    );
  }
  
  // Remove sidebars in admin area
  $form['base']['general_settings']['admin_remove_sidebars'] = array(
    '#type' => 'select',
    '#options' => array(
      '0' => t('No'),
      'sidebar_first' => t('Left'),
      'sidebar_second' => t('Right'),
      'both' => t('Both'),
    ),
    '#title' => t('Remove sidebars in admin areas'),
    '#default_value' => $settings['admin_remove_sidebars'],
  );

  // Layout settings
  $form['base']['layout'] = array(
    '#type' => 'fieldset',
    '#title' => t('Layout settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#attributes' => array('cs' => 'layout_settings'),
  );
  
  $form['base']['layout']['container'] = array(
    '#type' => 'select',
    '#title' => t('Select the number of columns in the grid.'),
    '#options' => array(
      '16' => '16 columns',
      '12' => '12 columns',
    ),
    '#default_value' => $settings['container'],
  );

  $form['base']['layout']['grid_layout'] = array(
    '#type' => 'radios',
    '#title' => t('Select the grid layout'),
    '#options' => array(
      'sidebar_second' => theme_image(drupal_get_path('theme', 'hydrogen') . '/includes/images/sidebar_second.png'),
      'sidebar_first'  => theme_image(drupal_get_path('theme', 'hydrogen') . '/includes/images/sidebar_first.png'), 
      'equal' => theme_image(drupal_get_path('theme', 'hydrogen') . '/includes/images/equal.png'), 
    ),
    '#default_value' => $settings['grid_layout'],
    '#suffix' => '<div cs="clear"></div>',
    '#attributes' => array('cs' => 'grid-layout'),
  );
  $form['base']['layout']['sidebar_first_width'] = array(
    '#type' => 'textfield',
    '#title' => t('First column width'),
    '#default_value' => $settings['sidebar_first_width'],
  );
  $form['base']['layout']['sidebar_second_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Last column width'),
    '#default_value' => $settings['sidebar_second_width'],
  );
  $form['base']['layout']['inset_column_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Inset column width'),
    '#default_value' => $settings['inset_column_width'],
  );
  $form['base']['layout']['wider_column'] = array(
    '#type' => 'checkbox',
    '#title' => t('Make single sidebar one column wider.'),
    '#description' => t('On pages where only one side bar is shown, increase the width of the side bar by 1 column.'), 
    '#default_value' => $settings['wider_column'],
  );

  // Development settings
  $form['base']['themedev'] = array(
    '#type' => 'fieldset',
    '#title' => t('Theme development settings'),
    '#collapsible' => TRUE,
    '#collapsed' => $settings['rebuild_registry'] ? FALSE : TRUE,
  );
  $form['base']['themedev']['rebuild_registry'] = array(
    '#type' => 'checkbox',
    '#title' => t('Rebuild theme registry on every page.'),
    '#default_value' => $settings['rebuild_registry'],
    '#description' => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
  );

  // Return theme settings form
  return $form;
}  
